Learn R Programming

lbiassurv (version 1.0)

lbfit.nonpar: Fits a Vardi corrected survival curve, a nonparametric survival cuve estimation.

Description

An extended version of the Kaplan-Miere estimator.

Usage

lbfit.nonpar(time, censor, initial = list(maxiter = 500, tol = 1e-06))

Arguments

time
The observed time as a vector.
censor
The survival indicator, 1 if censored, 0 otherwise.
initial
Some initialization for the nonparametric fit, as a list.

Value

  • The result of the function is an lbsurvfit object, including a step function for the nonparametric survival curve fit.

Details

A detailed description, or refer the reader to a work.

References

Vardi Paper

See Also

lbfit.par, lbsample

Examples

Run this code
mydata=lbsample(500,family="exponential",par=list(rate=1))
lbfit.nonpar(time=mydata$data,censor=mydata$censor)

Run the code above in your browser using DataLab